Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/sphinx-doc/sphinx.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJon Dufresne <jon.dufresne@gmail.com>2018-12-16 07:13:28 +0300
committerJon Dufresne <jon.dufresne@gmail.com>2018-12-19 03:23:10 +0300
commit6978918ffc14b0b096285adfa0c90f95de281efa (patch)
treea7ba01358ee56c41853c488dc5808818f08e79c6 /sphinx/search
parent4405366e223246045fb2ca465a8a3ebac1feb0e8 (diff)
Replace use of six.text_type with str
This removes the last use of the six package allowing Sphinx to remove it as a dependency.
Diffstat (limited to 'sphinx/search')
-rw-r--r--sphinx/search/__init__.py6
1 files changed, 2 insertions, 4 deletions
diff --git a/sphinx/search/__init__.py b/sphinx/search/__init__.py
index 2fd43ca4f..6100fc453 100644
--- a/sphinx/search/__init__.py
+++ b/sphinx/search/__init__.py
@@ -13,8 +13,6 @@ import re
import warnings
from os import path
-from six import text_type
-
from docutils import nodes
from sphinx import addnodes
@@ -351,9 +349,9 @@ class IndexBuilder:
otypes[domainname, type] = typeindex
otype = domain.object_types.get(type)
if otype:
# use unicode() to fire translation proxies
onames[typeindex] = (domainname, type,
- text_type(domain.get_type_name(otype)))
+ str(domain.get_type_name(otype)))
else:
onames[typeindex] = (domainname, type, type)
if anchor == fullname:
@@ -351,9 +349,9 @@ class IndexBuilder:
otype = domain.object_types.get(type)
if otype:
- # use unicode() to fire translation proxies
+ # use str() to fire translation proxies
onames[typeindex] = (domainname, type,